@@ -1,4 +1,4 @@
-# Copyrights 2006-2011 by Mark Overmeer.
+# Copyrights 2006-2012 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
@@ -8,7 +8,7 @@ no warnings 'recursion';  # trees can be quite deep
 
 package XML::Compile::Translate;
 use vars '$VERSION';
-$VERSION = '1.24';
+$VERSION = '1.25';
 
 
 # Errors are either in _class 'usage': called with request
@@ -683,7 +683,9 @@ sub element($)
         # Ugly xsi:type switch needed
         my %alt = ($comptype => $do3);
         foreach my $alttype (@{$self->{xsi_type}{$comptype}})
-        {   my ($ns, $local) = unpack_type $alttype;
+        {   next if $alttype eq $comptype;
+
+            my ($ns, $local) = unpack_type $alttype;
             my $prefix  = $node->lookupNamespacePrefix($ns);
             defined $prefix
                 or $prefix = $self->_registerNSprefix(undef, $ns, 1);
@@ -704,7 +706,6 @@ sub element($)
 
             $alt{$alttype} = $self->element($tree->descend($altnode));
         }
-
         $do4 = $self->makeXsiTypeSwitch($where, $name, $comptype, \%alt);
     }
 
@@ -1358,16 +1359,16 @@ sub simpleContentRestriction($$)
     my $node  = $tree->node;
     my $where = $tree->path . '#cres';
 
-    my $type;
+    my ($type, $typename);
     my $first = $tree->currentLocal || '';
     if($first eq 'simpleType')
     {   $type = $self->simpleType($tree->descend);
         $tree->nextChild;
     }
     elsif(my $basename  = $node->getAttribute('base'))
-    {   my $typename = $self->rel2abs($where, $node, $basename);
-        $type        = $self->blocked($where, simpleType => $type)
-                    || $self->typeByName($tree, $typename);
+    {   $typename = $self->rel2abs($where, $node, $basename);
+        $type     = $self->blocked($where, simpleType => $type)
+                 || $self->typeByName($tree, $typename);
     }
     else
     {   error __x"no base in complex-restriction, so simpleType required at {where}"
@@ -1378,7 +1379,7 @@ sub simpleContentRestriction($$)
         or error __x"not a simpleType in simpleContent/restriction at {where}"
              , where => $where, _class => 'schema';
 
-    $type->{st} = $self->applySimpleFacets($tree, $st, 0, $type);
+    $type->{st} = $self->applySimpleFacets($tree, $st, 0, $typename);
 
     $self->extendAttrs($type, {$self->attributeList($tree)});
 
