@@ -1,4 +1,4 @@
-# Copyrights 2006-2011 by Mark Overmeer.
+# Copyrights 2006-2012 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
@@ -7,7 +7,7 @@ use strict;
 
 package TestTools;
 use vars '$VERSION';
-$VERSION = '1.24';
+$VERSION = '1.25';
 
 use base 'Exporter';
 
@@ -72,7 +72,7 @@ sub test_rw($$$$;$$)
     my $tree   = writer_test $writer, $msg;
     my $untouched = eq_deeply $msg, $wasmsg;
 
-    ok($untouched, 'not tempored with written structure');
+    ok($untouched, 'not tempered with written structure');
     $untouched or warn Dumper $msg, $wasmsg;
 
     compare_xml($tree, $expect || $xml);
